@@ -233,7 +233,7 @@ impl<O: IsA<FwFcp>> FwFcpExtManual for O {
             connect_raw(
                 self.as_ptr() as *mut _,
                 b"responded\0".as_ptr() as *const _,
-                Some(std::mem::transmute::<_, unsafe extern "C" fn()>(
+                Some(std::mem::transmute::<*const (), unsafe extern "C" fn()>(
                     responded_trampoline::<Self, F> as *const (),
                 )),
                 std::boxed::Box::into_raw(f),
